@@ -5,7 +5,8 @@ always_inherited_properties = ["vulnerabilities"]
 
 
 def build_type_map(type_jsons):
-    type_map = {claim["credentialSubject"]["id"]: claim for claim in type_jsons}
+    type_map = {claim["credentialSubject"]
+                ["id"]: claim for claim in type_jsons}
     type_graph = build_claim_graph(type_map)
     sorted_nodes = list(nx.topological_sort(type_graph))
     for type_id in sorted_nodes:
@@ -20,18 +21,22 @@ def build_type_map(type_jsons):
             "vulnerabilities", []
         )
         inherited_properties = {"vulnerabilities": type_vulnerabilities}
-        for parent in parents:
+        for index, parent in enumerate(parents):
             parent_id = parent["id"]
-            parent_properties = parent.get("properties") if parent.get("properties") is not None else []
+            parent_properties = parent.get("properties") if parent.get(
+                "properties") is not None else []
             properties_to_inherit = set(
                 always_inherited_properties + parent_properties
             )
+            parentType = type_map[parent_id]
+            try:
+                type_instance["credentialSubject"]["parents"][index]["name"] = parentType["credentialSubject"]["name"]
+            except KeyError:
+                raise Exception(f"parent {parent_id} missing name")
             for property in properties_to_inherit:
                 property_to_inherit = None
                 try:
-                    property_to_inherit = type_map[parent_id]["credentialSubject"][
-                        property
-                    ]
+                    property_to_inherit = parentType["credentialSubject"][property]
                 except KeyError:
                     raise KeyError(
                         f"Attempted to inherit missing property {property} from {parent_id} in {type_id}"
@@ -39,7 +44,8 @@ def build_type_map(type_jsons):
                 if property_to_inherit is not None:
                     if property in inherited_properties:
                         if type(inherited_properties[property]) == list:
-                            inherited_properties[property] + property_to_inherit
+                            inherited_properties[property] + \
+                                property_to_inherit
                         else:
                             raise KeyError(
                                 f"""Duplicate inherited properties in type definition {type_id},
@@ -54,7 +60,13 @@ def build_type_map(type_jsons):
             **type_instance["credentialSubject"],
             **inherited_properties,
         }
-        type_map[type_id]["credentialSubject"]["children"] = [
-            {"id": child_id} for child_id in list(type_graph.successors(type_id))
-        ]
+        children = list(type_graph.successors(type_id))
+        children_array = []
+        for child_id in children:
+            try:
+                child_data = {"id": child_id, "name": type_map[child_id]["credentialSubject"]["name"]}
+                children_array.append(child_data)
+            except KeyError:
+                raise Exception(f"child {child_id} missing name")
+        type_map[type_id]["credentialSubject"]["children"] = children_array
     return type_map
